Kaidoku: Player, solver and creater of sudoku puzzles
=====================================================

Kaidoku can solve sudoku puzzles as shown in the figure, play with the puzzles and create sudoku puzzles with a command-line interface.

.. figure:: https://sekika.github.io/kaidoku/img/3-1.jpg
   :align: center
   :alt: sudoku

Kaidoku is a

- player of sudoku. You can play original sudoku puzzles of various level of difficulty with command line interface. You can get hints when you want.
- solver of sudoku. It can solve a sudoku puzzle and show the procedure of solving a sudoku puzzle with various logics. It evaluates if a given puzzle is valid sudoku with unique solution.
- creater of sudoku. It can create new sudoku puzzles. The puzzles shipped with this program was created by the program itself. 

Online player
---------------------

25000 sudoku puzzles classified with 9 difficulty levels are available online.

https://sekika.github.io/kaidoku/sudoku

Full document
---------------------

Document is availabe in English and Japanese.

https://sekika.github.io/kaidoku/

Supported logics
---------------------

- Naked single, pair, triple and quad
- Hidden single, pair, triple and quad
- Pointing pair and triple
- X-wing family (Swordfish and Jellyfish)
- XY-wing and XYZ-wing
- Remote pairs
- Chain of pairs
- Trial and search
